<?php

namespace App\Http\Controllers\admin;

use App\Models\Pack;
use App\Http\Controllers\Controller;
use App\Models\Tool;
use Illuminate\Http\Request;

class PackController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $packs = Pack::all();
        foreach ($packs as $pack) {
            $pack->tools;
        }
    }

    /**
     * Display the specified resource.
     */
    public function show($id)
    {
        $pack = Pack::find($id);

        return view('pack.show', ['pack' => $pack]);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Pack $pack)
    {
        $this->authorize('edit', $pack);
        $tools = Tool::all();

        return view('admin.pack.edit', ['pack' => $pack, 'tools' => $tools]);
    }


    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        $data = $request->validate([
            'name' => 'required',
            'quantity' => 'required',
        ]);

        $pack = Pack::find($id);
        $pack->update($data);

        if ($request->has('tools')) {
            $pack->tools()->sync($request->tools);
        }



        return redirect()->route('packs.show', $pack);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy($id)
    {
        $pack = Pack::find($id);
        $pack->delete();

        return redirect()->route('home');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $this->authorize('create', Pack::class);
        $tools = Tool::all();
        return view('admin.pack.create', ['tools' => $tools]);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $data = $request->validate([
            'name' => 'required',
            'quantity' => 'required',
        ]);

        $pack = new Pack();
        $pack->fill($data);
        $pack->save();

        if ($request->has('tools')) {
            $pack->tools()->attach($request->tools);
        }

        return redirect()->route('packs.show', $pack);
    }
}
