<?php

namespace App\Http\Controllers\admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\Tool;
use App\Models\Pack;

class ToolsController extends Controller
{
    public function index()
    {
        $this->authorize('viewAny', Tool::class);
        $tools = Tool::all();
    }

    public function show($tool)
    {
        $this->authorize('view', $tool);
        return view('admin.tool.show', ['tool' => $tool]);
    }

    public function create()
    {
        $this->authorize('create', Tool::class);
        return view('admin.tool.create');
    }

    public function edit(Tool $tool)
    {
        $this->authorize('edit', $tool);
        return view('admin.tool.edit', ['tool' => $tool]);
    }

    public function store()
    {
        $this->authorize('create', Tool::class);
        $data = request()->validate([
            'name' => 'required',
            'description' => 'required',
            'image' => 'required',
            'tags' => 'required',
            'quantity' => 'required',
        ]);
        Tool::create($data);
    }

    public function update(Request $request, Tool $tool)
    {
        $this->authorize('update', $tool);

        $data = $request->validate([
            'name' => 'required',
            'description' => 'required',
            'image' => 'required',
            'tags' => 'required',
            'quantity' => 'required',
        ]);
        $tool->update($data);

        return redirect()->route('tools.show', $tool);
    }

    public function destroy(Tool $tool)
    {
        $this->authorize('delete', $tool);
        $tool->delete();

        return redirect()->route('home');
    }
}
